@@ -40,7 +40,7 @@
 #include <ucommon/object.h>
 #endif
 
-NAMESPACE_UCOMMON
+namespace ucommon {
 
 class OrderedObject;
 
@@ -137,7 +137,7 @@ public:
      * @return next linked object in list.
      */
     inline LinkedObject *getNext(void) const
-        {return Next;};
+        {return Next;}
 };
 
 /**
@@ -162,7 +162,7 @@ public:
      * @return next reusable object in list.
      */
     inline ReusableObject *getNext(void)
-        {return static_cast<ReusableObject*>(LinkedObject::getNext());};
+        {return static_cast<ReusableObject*>(LinkedObject::getNext());}
 };
 
 /**
@@ -259,28 +259,28 @@ public:
      * @return LinkedObject member of index.
      */
     inline LinkedObject *getIndexed(unsigned index) const
-        {return LinkedObject::getIndexed((LinkedObject*)head, index);};
+        {return LinkedObject::getIndexed((LinkedObject*)head, index);}
 
     /**
      * Return first object in list for iterators.
      * @return first object in list.
      */
     inline LinkedObject *begin(void) const
-        {return (LinkedObject*)(head);};
+        {return (LinkedObject*)(head);}
 
     /**
      * Return last object in list for iterators.
      * @return last object in list.
      */
     inline LinkedObject *end(void) const
-        {return (LinkedObject*)(tail);};
+        {return (LinkedObject*)(tail);}
 
     /**
      * Return head object pointer.
      * @return head pointer.
      */
     inline LinkedObject *operator*() const
-        {return (LinkedObject*)(head);};
+        {return (LinkedObject*)(head);}
 
     /**
      * Assign ordered index.
@@ -352,7 +352,7 @@ public:
      * @return next ordered object.
      */
     inline OrderedObject *getNext(void) const
-        {return static_cast<OrderedObject *>(LinkedObject::getNext());};
+        {return static_cast<OrderedObject *>(LinkedObject::getNext());}
 };
 
 /**
@@ -532,7 +532,7 @@ public:
      * @return next linked object in list.
      */
     inline NamedObject *getNext(void) const
-        {return static_cast<NamedObject*>(LinkedObject::getNext());};
+        {return static_cast<NamedObject*>(LinkedObject::getNext());}
 
     /**
      * Get the named id string of this object.
@@ -556,7 +556,7 @@ public:
      * @return true if equal.
      */
     inline bool equal(const char *name) const
-        {return (compare(name) == 0);};
+        {return (compare(name) == 0);}
 
     /**
      * Comparison operator between our name and a string.
@@ -564,7 +564,7 @@ public:
      * @return true if equal.
      */
     inline bool operator==(const char *name) const
-        {return compare(name) == 0;};
+        {return compare(name) == 0;}
 
     /**
      * Comparison operator between our name and a string.
@@ -572,7 +572,7 @@ public:
      * @return true if not equal.
      */
     inline bool operator!=(const char *name) const
-        {return compare(name) != 0;};
+        {return compare(name) != 0;}
 };
 
 /**
@@ -675,7 +675,7 @@ public:
      * @return first child node or NULL if no children.
      */
     inline NamedTree *getFirst(void) const
-        {return static_cast<NamedTree *>(Child.begin());};
+        {return static_cast<NamedTree *>(Child.begin());}
 
     /**
      * Get parent node we are listed as a child on.
@@ -690,28 +690,28 @@ public:
      * @return indexed child node.
      */
     inline NamedTree *getIndexed(unsigned index) const
-        {return static_cast<NamedTree *>(Child.getIndexed(index));};
+        {return static_cast<NamedTree *>(Child.getIndexed(index));}
 
     /**
      * Get the ordered index of our child nodes.
      * @return ordered index of our children.
      */
     inline OrderedIndex *getIndex(void) const
-        {return const_cast<OrderedIndex*>(&Child);};
+        {return const_cast<OrderedIndex*>(&Child);}
 
     /**
      * Test if this node has a name.
      * @return true if name is set.
      */
     inline operator bool() const
-        {return (Id != NULL);};
+        {return (Id != NULL);}
 
     /**
      * Test if this node is unnamed.
      * @return false if name is set.
      */
     inline bool operator!() const
-        {return (Id == NULL);};
+        {return (Id == NULL);}
 
     /**
      * Set or replace the name id of this node.  This will free the string
@@ -731,14 +731,14 @@ public:
      * @return true if node contains child nodes.
      */
     inline bool is_leaf(void) const
-        {return (Child.begin() == NULL);};
+        {return (Child.begin() == NULL);}
 
     /**
      * Test if node is root node.
      * @return true if node is root node.
      */
     inline bool is_root(void) const
-        {return (Parent == NULL);};
+        {return (Parent == NULL);}
 
     /**
      * Add leaf to a trunk, by order.  If NULL, just remove.
@@ -757,7 +757,7 @@ public:
      * @param trunk we add leaf node to, NULL to delist.
      */
     inline void relist(NamedTree *trunk = NULL)
-        {relistTail(trunk);};
+        {relistTail(trunk);}
 };
 
 /**
@@ -823,28 +823,28 @@ public:
      * @return true if we are the first node in a list.
      */
     inline bool is_head(void) const
-        {return Root->head == (OrderedObject *)this;};
+        {return Root->head == (OrderedObject *)this;}
 
     /**
      * Test if we are at the end of a list.
      * @return true if we are the last node in a list.
      */
     inline bool is_tail(void) const
-        {return Root->tail == (OrderedObject *)this;};
+        {return Root->tail == (OrderedObject *)this;}
 
     /**
      * Get previous node in the list for reverse iteration.
      * @return previous node in list.
      */
     inline LinkedList *getPrev(void) const
-        {return Prev;};
+        {return Prev;}
 
     /**
      * Get next node in the list when iterating.
      * @return next node in list.
      */
     inline LinkedList *getNext(void) const
-        {return static_cast<LinkedList*>(LinkedObject::getNext());};
+        {return static_cast<LinkedList*>(LinkedObject::getNext());}
 
     /**
      * Insert object behind our object.
@@ -869,21 +869,21 @@ public:
      * @param object to add to list.
      */
     inline void operator+=(LinkedList *object)
-        {insertTail(object);};
+        {insertTail(object);}
 
     /**
      * Insert object in front of our object.
      * @param object to add to list.
      */
     inline void operator-=(LinkedList *object)
-        {insertHead(object);};
+        {insertHead(object);}
 
     /**
      * Insert object in list with our object.
      * @param object to add to list.
      */
     inline void operator*=(LinkedList *object)
-        {insert(object);};
+        {insert(object);}
 };
 
 /**
@@ -958,7 +958,7 @@ public:
      * @return object popped from stack or NULL if empty.
      */
     inline LinkedObject *pop(void)
-        {return ObjectStack::pull();};
+        {return ObjectStack::pull();}
 };
 
 
@@ -1069,14 +1069,14 @@ public:
      * @param name of our object.
      */
     inline named_value(LinkedObject **root, char *name)
-        {LinkedObject::enlist(root); O::id = name;};
+        {LinkedObject::enlist(root); O::id = name;}
 
     /**
      * Assign embedded value from related type.
      * @param typed_value to assign.
      */
     inline void operator=(const T& typed_value)
-        {this->set(typed_value);};
+        {this->set(typed_value);}
 
     /**
      * Find embedded object in chain by name.
@@ -1085,7 +1085,7 @@ public:
      * @return composite object found by name or NULL if not found.
      */
     inline static named_value find(named_value *first, const char *name)
-        {return static_cast<named_value *>(NamedObject::find(first, name));};
+        {return static_cast<named_value *>(NamedObject::find(first, name));}
 };
 
 /**
@@ -1103,21 +1103,21 @@ public:
     /**
      * Create embedded value object unlinked.
      */
-    inline linked_value() {};
+    inline linked_value() {}
 
     /**
      * Construct embedded object on a linked list.
      * @param root node or pointer for list.
      */
     inline linked_value(LinkedObject **root)
-        {LinkedObject::enlist(root);};
+        {LinkedObject::enlist(root);}
 
     /**
      * Construct embedded object on an ordered list.
      * @param index pointer for the ordered list.
      */
     inline linked_value(OrderedIndex *index)
-        {O::enlist(index);};
+        {O::enlist(index);}
 
     /**
      * Assign embedded value from related type and link to list.
@@ -1125,7 +1125,7 @@ public:
      * @param typed_value to assign.
      */
     inline linked_value(LinkedObject **root, const T& typed_value)
-        {LinkedObject::enlist(root); this->set(typed_value);};
+        {LinkedObject::enlist(root); this->set(typed_value);}
 
     /**
      * Assign embedded value from related type and add to list.
@@ -1133,14 +1133,14 @@ public:
      * @param typed_value to assign.
      */
     inline linked_value(OrderedIndex *index, const T& typed_value)
-        {O::enlist(index); this->set(typed_value);};
+        {O::enlist(index); this->set(typed_value);}
 
     /**
      * Assign embedded value from related type.
      * @param typed_value to assign.
      */
     inline void operator=(const T& typed_value)
-        {this->set(typed_value);};
+        {this->set(typed_value);}
 };
 
 /**
@@ -1296,105 +1296,105 @@ public:
      * @param pointer to first member of a linked list.
      */
     inline linked_pointer(T *pointer)
-        {ptr = pointer;};
+        {ptr = pointer;}
 
     /**
      * Create a copy of an existing linked pointer.
      * @param pointer to copy from.
      */
     inline linked_pointer(const linked_pointer &pointer)
-        {ptr = pointer.ptr;};
+        {ptr = pointer.ptr;}
 
     /**
      * Create a linked pointer assigned from a raw linked object pointer.
      * @param pointer to linked object.
      */
     inline linked_pointer(LinkedObject *pointer)
-        {ptr = static_cast<T*>(pointer);};
+        {ptr = static_cast<T*>(pointer);}
 
     inline linked_pointer(const LinkedObject *pointer)
-        {ptr = static_cast<T*>(pointer);};
+        {ptr = static_cast<T*>(pointer);}
 
     /**
      * Create a linked pointer to examine an ordered index.
      * @param index of linked objects to iterate through.
      */
     inline linked_pointer(OrderedIndex *index)
-        {ptr = static_cast<T*>(index->begin());};
+        {ptr = static_cast<T*>(index->begin());}
 
     /**
      * Create a linked pointer not attached to a list.
      */
     inline linked_pointer()
-        {ptr = NULL;};
+        {ptr = NULL;}
 
     /**
      * Assign our typed iterative pointer from a matching typed object.
      * @param pointer to typed object.
      */
     inline void operator=(T *pointer)
-        {ptr = pointer;};
+        {ptr = pointer;}
 
     /**
      * Assign our pointer from another pointer.
      * @param pointer to assign from.
      */
     inline void operator=(linked_pointer &pointer)
-        {ptr = pointer.ptr;};
+        {ptr = pointer.ptr;}
 
     /**
      * Assign our pointer from the start of an ordered index.
      * @param index to assign pointer from.
      */
     inline void operator=(OrderedIndex *index)
-        {ptr = static_cast<T*>(index->begin());};
+        {ptr = static_cast<T*>(index->begin());}
 
     /**
      * Assign our pointer from a generic linked object pointer.
      * @param pointer of linked list.
      */
     inline void operator=(LinkedObject *pointer)
-        {ptr = static_cast<T*>(pointer);};
+        {ptr = static_cast<T*>(pointer);}
 
     /**
      * Return member from typed object our pointer references.
      * @return evaluated member of object we point to.
      */
     inline T* operator->() const
-        {return ptr;};
+        {return ptr;}
 
     /**
      * Return object we currently point to.
      * @return object linked pointer references.
      */
     inline T* operator*() const
-        {return ptr;};
+        {return ptr;}
 
     /**
      * Return object we point to by casting.
      * @return object linked pointer references.
      */
     inline operator T*() const
-        {return ptr;};
+        {return ptr;}
 
     /**
      * Move (iterate) pointer to previous member in double linked list.
      */
     inline void prev(void)
-        {ptr = static_cast<T*>(ptr->getPrev());};
+        {ptr = static_cast<T*>(ptr->getPrev());}
 
     /**
      * Move (iterate) pointer to next member in linked list.
      */
     inline void next(void)
-        {ptr = static_cast<T*>(ptr->getNext());};
+        {ptr = static_cast<T*>(ptr->getNext());}
 
     /**
      * Get the next member in linked list.  Do not change who we point to.
      * @return next member in list or NULL if end of list.
      */
     inline T *getNext(void) const
-        {return static_cast<T*>(ptr->getNext());};
+        {return static_cast<T*>(ptr->getNext());}
 
     /**
      * Get the previous member in double linked list.  Do not change who we
@@ -1402,54 +1402,54 @@ public:
      * @return previous member in list or NULL if start of list.
      */
     inline T *getPrev(void) const
-        {return static_cast<T*>(ptr->getPrev());};
+        {return static_cast<T*>(ptr->getPrev());}
 
     /**
      * Move (iterate) pointer to next member in linked list.
      */
     inline void operator++()
-        {ptr = static_cast<T*>(ptr->getNext());};
+        {ptr = static_cast<T*>(ptr->getNext());}
 
     /**
      * Move (iterate) pointer to previous member in double linked list.
      */
     inline void operator--()
-        {ptr = static_cast<T*>(ptr->getPrev());};
+        {ptr = static_cast<T*>(ptr->getPrev());}
 
     /**
      * Test for next member in linked list.
      * @return true if there is more members after current one.
      */
     inline bool is_next(void) const
-        {return (ptr->getNext() != NULL);};
+        {return (ptr->getNext() != NULL);}
 
     /**
      * Test for previous member in double linked list.
      * @return true if there is more members before current one.
      */
     inline bool is_prev(void) const
-        {return (ptr->getPrev() != NULL);};
+        {return (ptr->getPrev() != NULL);}
 
     /**
      * Test if linked pointer is set/we are not at end of list.
      * @return true if we are not at end of list.
      */
     inline operator bool() const
-        {return (ptr != NULL);};
+        {return (ptr != NULL);}
 
     /**
      * Test if linked list is empty/we are at end of list.
      * @return true if we are at end of list.
      */
     inline bool operator!() const
-        {return (ptr == NULL);};
+        {return (ptr == NULL);}
 
     /**
      * Return pointer to our linked pointer to use as root node of a chain.
      * @return our object pointer as a root index.
      */
     inline LinkedObject **root(void) const
-        {T **r = &ptr; return (LinkedObject**)r;};
+        {T **r = &ptr; return (LinkedObject**)r;}
 };
 
 /**
@@ -1469,19 +1469,19 @@ public:
     /**
      * Construct a multimap node.
      */
-    inline multimap() : MultiMap(P) {};
+    inline multimap() : MultiMap(P) {}
 
     /**
      * Destroy a multimap object.
      */
-    inline ~multimap() {};
+    inline ~multimap() {}
 
     /**
      * Return the typed value of this node.
      * @return reference to value of node.
      */
     inline T &get(void) const
-        {return value;};
+        {return value;}
 
     /**
      * Return next multimap typed object.
@@ -1489,35 +1489,35 @@ public:
      * @return multimap typed.
      */
     inline multimap *next(unsigned path)
-        {return static_cast<multimap*>(MultiMap::next(path));};
+        {return static_cast<multimap*>(MultiMap::next(path));}
 
     /**
      * Return typed value of this node by pointer reference.
      * @return value of node.
      */
     inline T& operator*() const
-        {return value;};
+        {return value;}
 
     /**
      * Set the pointer of a pointer based value tree.
      * @param pointer to set.
      */
     inline void setPointer(const T pointer)
-        {value = pointer;};
+        {value = pointer;}
 
     /**
      * Set the value of a data based value tree.
      * @param reference to value to copy into node.
      */
     inline void set(const T &reference)
-        {value = reference;};
+        {value = reference;}
 
     /**
      * Assign the value of our node.
      * @param data value to assign.
      */
     inline void operator=(const T& data)
-        {value = data;};
+        {value = data;}
 
     /**
      * Find multimap key entry.
@@ -1529,7 +1529,7 @@ public:
      * @return multipath typed object.
      */
     inline static multimap *find(unsigned path, MultiMap **index, caddr_t key, unsigned size, unsigned keysize = 0)
-        {return static_cast<multimap*>(MultiMap::find(path, index, key, size, keysize));};
+        {return static_cast<multimap*>(MultiMap::find(path, index, key, size, keysize));}
 };
 
 /**
@@ -1561,7 +1561,7 @@ public:
      * named as a stand-alone node or unnamed.
      * @param name of the node we are creating.
      */
-    inline treemap(char *name = NULL) : NamedTree(name) {};
+    inline treemap(char *name = NULL) : NamedTree(name) {}
 
     /**
      * Construct a copy of the treemap object.
@@ -1575,7 +1575,7 @@ public:
      * @param parent of this node to attach.
      * @param name of this node.
      */
-    inline treemap(treemap *parent, char *name) : NamedTree(parent, name) {};
+    inline treemap(treemap *parent, char *name) : NamedTree(parent, name) {}
 
     /**
      * Construct a child node on an existing tree and assign it's value.
@@ -1584,21 +1584,21 @@ public:
      * @param reference to value to assign to this node.
      */
     inline treemap(treemap *parent, char *name, T& reference) :
-        NamedTree(parent, name) {value = reference;};
+        NamedTree(parent, name) {value = reference;}
 
     /**
      * Return the typed value of this node.
      * @return reference to value of node.
      */
     inline const T& get(void) const
-        {return value;};
+        {return value;}
 
     /**
      * Return typed value of this node by pointer reference.
      * @return value of node.
      */
     inline const T& operator*() const
-        {return value;};
+        {return value;}
 
     /**
      * Return value from tree element when value is a pointer.
@@ -1606,49 +1606,49 @@ public:
      * @return value of node.
      */
     static inline T getPointer(treemap *node)
-        {return (node == NULL) ? NULL : node->value;};
+        {return (node == NULL) ? NULL : node->value;}
 
     /**
      * Test if this node is a leaf node for a tree pointer table.
      * @return true if value pointer is not NULL and there are no children.
      */
     inline bool is_attribute(void) const
-        {return (!Child.begin() && value != NULL);};
+        {return (!Child.begin() && value != NULL);}
 
     /**
      * Get the pointer of a pointer based value tree.
      * @return value pointer of node.
      */
     inline const T getPointer(void) const
-        {return value;};
+        {return value;}
 
     /**
      * Get the data value of a data based value tree.
      * @return data value of node.
      */
     inline const T& getData(void) const
-        {return value;};
+        {return value;}
 
     /**
      * Set the pointer of a pointer based value tree.
      * @param pointer to set.
      */
     inline void setPointer(const T pointer)
-        {value = pointer;};
+        {value = pointer;}
 
     /**
      * Set the value of a data based value tree.
      * @param reference to value to copy into node.
      */
     inline void set(const T& reference)
-        {value = reference;};
+        {value = reference;}
 
     /**
      * Assign the value of our node.
      * @param data value to assign.
      */
     inline void operator=(const T& data)
-        {value = data;};
+        {value = data;}
 
     /**
      * Get child member node by index.
@@ -1656,14 +1656,14 @@ public:
      * @return node or NULL if past end.
      */
     inline treemap *getIndexed(unsigned index) const
-        {return static_cast<treemap*>(Child.getIndexed(index));};
+        {return static_cast<treemap*>(Child.getIndexed(index));}
 
     /**
      * Get the typed parent node for our node.
      * @return parent node or NULL if root of tree.
      */
     inline treemap *getParent(void) const
-        {return static_cast<treemap*>(Parent);};
+        {return static_cast<treemap*>(Parent);}
 
     /**
      * Get direct typed child node of our node of specified name.  This
@@ -1672,7 +1672,7 @@ public:
      * @return typed child node pointer or NULL if not found.
      */
     inline treemap *getChild(const char *name) const
-        {return static_cast<treemap*>(NamedTree::getChild(name));};
+        {return static_cast<treemap*>(NamedTree::getChild(name));}
 
     /**
      * Find a direct typed leaf node on our node.  A leaf node is a node that
@@ -1681,7 +1681,7 @@ public:
      * @return typed leaf node object of leaf or NULL.
      */
     inline treemap *getLeaf(const char *name) const
-        {return static_cast<treemap*>(NamedTree::getLeaf(name));};
+        {return static_cast<treemap*>(NamedTree::getLeaf(name));}
 
     /**
      * Get the value pointer of a leaf node of a pointer tree.  This allows
@@ -1691,7 +1691,7 @@ public:
      * @return value of leaf pointer if found and contains value, or NULL.
      */
     inline T getValue(const char *name) const
-        {return getPointer(getLeaf(name));};
+        {return getPointer(getLeaf(name));}
 
     /**
      * Find a subnode from our node by name.  This performs a recursive
@@ -1700,7 +1700,7 @@ public:
      * @return typed node that is found or NULL if none is found.
      */
     inline treemap *find(const char *name) const
-        {return static_cast<treemap*>(NamedTree::find(name));};
+        {return static_cast<treemap*>(NamedTree::find(name));}
 
     /**
      * Find a subnode by pathname.  This is the same as the NamedTree
@@ -1709,7 +1709,7 @@ public:
      * @return typed node that is found at path or NULL.
      */
     inline treemap *path(const char *path) const
-        {return static_cast<treemap*>(NamedTree::path(path));};
+        {return static_cast<treemap*>(NamedTree::path(path));}
 
     /**
      * Search for a leaf node of our node.  This performs a recursive
@@ -1718,14 +1718,14 @@ public:
      * @return typed not that is found or NULL if none is found.
      */
     inline treemap *leaf(const char *name) const
-        {return static_cast<treemap*>(NamedTree::leaf(name));};
+        {return static_cast<treemap*>(NamedTree::leaf(name));}
 
     /**
      * Get first child of our node.  This is useful for iterating children.
      * @return first child or NULL.
      */
     inline treemap *getFirst(void) const
-        {return static_cast<treemap*>(NamedTree::getFirst());};
+        {return static_cast<treemap*>(NamedTree::getFirst());}
 };
 
 /**
@@ -1746,21 +1746,21 @@ public:
      * Destroy the hash map by puring the index chains.
      */
     inline ~keymap()
-        {NamedObject::purge(idx, M);};
+        {NamedObject::purge(idx, M);}
 
     /**
      * Retrieve root of index to use in NamedObject constructors.
      * @return root node of index.
      */
     inline NamedObject **root(void) const
-        {return idx;};
+        {return idx;}
 
     /**
      * Retrieve key size to use in NamedObject constructors.
      * @return key size of hash map.
      */
     inline unsigned limit(void) const
-        {return M;};
+        {return M;}
 
     /**
      * Find a typed object derived from NamedObject in the hash map by name.
@@ -1768,7 +1768,7 @@ public:
      * @return typed object if found through map or NULL.
      */
     inline T *get(const char *name) const
-        {return static_cast<T*>(NamedObject::map(idx, name, M));};
+        {return static_cast<T*>(NamedObject::map(idx, name, M));}
 
     /**
      * Find a typed object derived from NamedObject in the hash map by name.
@@ -1776,7 +1776,7 @@ public:
      * @return typed object if found through map or NULL.
      */
     inline T& operator[](const char *name) const
-        {return static_cast<T*>(NamedObject::map(idx, name, M));};
+        {return static_cast<T*>(NamedObject::map(idx, name, M));}
 
     /**
      * Add a typed object derived from NamedObject to the hash map by name.
@@ -1784,7 +1784,7 @@ public:
      * @param object to add.
      */
     inline void add(const char *name, T& object)
-        {object.NamedObject::add(idx, name, M);};
+        {object.NamedObject::add(idx, name, M);}
 
     /**
      * Add a typed object derived from NamedObject to the hash map by name.
@@ -1792,7 +1792,7 @@ public:
      * @param object to add.
      */
     inline void add(const char *name, T *object)
-        {object->NamedObject::add(idx, name, M);};
+        {object->NamedObject::add(idx, name, M);}
 
     /**
      * Remove a typed object derived from NamedObject to the hash map by name.
@@ -1800,14 +1800,14 @@ public:
      * @return object removed if found or NULL.
      */
     inline T *remove(const char *name)
-        {return static_cast<T*>(NamedObject::remove(idx, name, M));};
+        {return static_cast<T*>(NamedObject::remove(idx, name, M));}
 
     /**
      * Find first typed object in hash map to iterate.
      * @return first typed object or NULL if nothing in list.
      */
     inline T *begin(void) const
-        {return static_cast<T*>(NamedObject::skip(idx, NULL, M));};
+        {return static_cast<T*>(NamedObject::skip(idx, NULL, M));}
 
     /**
      * Find next typed object in hash map for iteration.
@@ -1815,14 +1815,14 @@ public:
      * @return next iterative object or NULL if past end of map.
      */
     inline T *next(T *current) const
-        {return static_cast<T*>(NamedObject::skip(idx, current, M));};
+        {return static_cast<T*>(NamedObject::skip(idx, current, M));}
 
     /**
      * Count the number of typed objects in our hash map.
      * @return count of typed objects.
      */
     inline unsigned count(void) const
-        {return NamedObject::count(idx, M);};
+        {return NamedObject::count(idx, M);}
 
     /**
      * Convert our hash map into a linear object pointer array.  The
@@ -1831,7 +1831,7 @@ public:
      * @return array of typed named object pointers.
      */
     inline T **index(void) const
-        {return NamedObject::index(idx, M);};
+        {return NamedObject::index(idx, M);}
 
     /**
      * Convert our hash map into an alphabetically sorted linear object
@@ -1840,7 +1840,7 @@ public:
      * @return sorted array of typed named object pointers.
      */
     inline T **sort(void) const
-        {return NamedObject::sort(NamedObject::index(idx, M));};
+        {return NamedObject::sort(NamedObject::index(idx, M));}
 
     /**
      * Convenience typedef for iterative pointer.
@@ -1863,7 +1863,7 @@ public:
      * @return pointer to index root.
      */
     inline NamedObject **root(void)
-        {return static_cast<NamedObject**>(&head);};
+        {return static_cast<NamedObject**>(&head);}
 
     /**
      * Return first item in ordered list.  This is commonly used to
@@ -1871,7 +1871,7 @@ public:
      * @return first item in list or NULL if empty.
      */
     inline T *begin(void)
-        {return static_cast<T*>(head);};
+        {return static_cast<T*>(head);}
 
     /**
      * Return last item in ordered list.  This is commonly used to determine
@@ -1879,7 +1879,7 @@ public:
      * @return last item in list or NULL if empty.
      */
     inline T *end(void)
-        {return static_cast<T*>(tail);};
+        {return static_cast<T*>(tail);}
 
     /**
      * Create a new typed named object with default constructor.
@@ -1888,7 +1888,7 @@ public:
      * @return typed named object.
      */
     inline T *create(const char *name)
-        {return new T(this, name);};
+        {return new T(this, name);}
 
     /**
      * Iterate next object in list.
@@ -1896,7 +1896,7 @@ public:
      * @return next logical object in linked list or NULL if end.
      */
     inline T *next(LinkedObject *current)
-        {return static_cast<T*>(current->getNext());};
+        {return static_cast<T*>(current->getNext());}
 
     /**
      * Find a specific object by name.
@@ -1904,10 +1904,10 @@ public:
      * @return type named object that matches or NULL if not found.
      */
     inline T *find(const char *name)
-        {return static_cast<T*>(NamedObject::find(begin(), name));};
+        {return static_cast<T*>(NamedObject::find(begin(), name));}
 
     inline T *offset(unsigned offset)
-        {return static_cast<T*>(OrderedIndex::find(offset));};
+        {return static_cast<T*>(OrderedIndex::find(offset));}
 
     /**
      * Retrieve a specific object by position in list.
@@ -1915,10 +1915,10 @@ public:
      * @return type named object or NULL if past end of list.
      */
     inline T& operator[](unsigned offset)
-        {return static_cast<T&>(OrderedIndex::find(offset));};
+        {return static_cast<T&>(OrderedIndex::find(offset));}
 
     inline T& operator[](const char *name)
-        {return static_cast<T&>(NamedObject::find(begin(), name));};
+        {return static_cast<T&>(NamedObject::find(begin(), name));}
 
     /**
      * Convert our linked list into a linear object pointer array.  The
@@ -1927,7 +1927,7 @@ public:
      * @return array of typed named object pointers.
      */
     inline T **index(void)
-        {return static_cast<T**>(OrderedIndex::index());};
+        {return static_cast<T**>(OrderedIndex::index());}
 
     /**
      * Convert our linked list into an alphabetically sorted linear object
@@ -1936,7 +1936,7 @@ public:
      * @return array of typed named object pointers.
      */
     inline T **sort(void)
-        {return static_cast<T**>(NamedObject::sort(index()));};
+        {return static_cast<T**>(NamedObject::sort(index()));}
 
     /**
      * Convenience typedef for iterative pointer.
@@ -1964,6 +1964,6 @@ typedef OrderedIndex objfifo_t;
  */
 typedef ObjectQueue objqueue_t;
 
-END_NAMESPACE
+} // namespace ucommon
 
 #endif
