@@ -24,7 +24,7 @@
 
 #include <stdio.h>
 
-using namespace UCOMMON_NAMESPACE;
+using namespace ucommon;
 using namespace std;
 
 class ThreadOut: public JoinableThread
